/** Current version of the message API. */
export interface MessageApiVersion
{
    /** Major version will be increased for every breaking change in the api. */
    major: 2;

    /** Minor version will be increased for ever non-breaking change in the api. */
    minor: 4;

    /** Patch version will be increased for bug-fix releases. */
    patch: 0;

    /** If not empty the pre-release tag indicates a pre-release (e.g. alpha, beta) */
    preRelease: "";
}

/** Messages to send to the host window. */
export type HostMessageType =
    "wbkHost.getConfiguration" |
    "wbkHost.getCustomArticle" |
    "wbkHost.getCustomCatalogArticles" |
    "wbkHost.projectTitleChanged" |
    "wbkHost.saveProject" |
    "wbkHost.sessionModifications" |
    "wbkHost.reportGenerated" |
    "wbkHost.finishIntegrationCanceled" |
    "wbkHost.done";

/** Messages to send to the basket window. */
export type WbkMessageType =
    "wbk.configuration" |
    "wbk.updateUserAccessToken" |
    "wbk.customArticle" |
    "wbk.customCatalogArticles" |
    "wbk.setProjectTitle" |
    "wbk.saveProjectDone" |
    "wbk.getSessionModifications" |
    "wbk.finishIntegration";

/** Base message interface. */
export interface BaseMessage
{
    type: HostMessageType | WbkMessageType;
    parameter?: unknown;
}