/** Returns the configuration for the custom catalogs used for the `wbk.configuration` message. */
function getCustomCatalogConfiguration() {
    return [
        //register custom catalog
        {
            id: "exampleCustomCatalog",
            label: "My Custom Catalog",
            imageUrl: "https://integration.basket.pcon-solutions.com/example-data/custom-catalog/catalog-logo.jpg"
        },
        //register external catalog
        {
            id: "exampleExternalCatalog",
            label: "My External Catalog",
            imageUrl: "https://integration.basket.pcon-solutions.com/example-data/external-catalog/catalog-logo.jpg",
            externalUrl: "https://integration.basket.pcon-solutions.com/example-data/external-catalog/catalog.html"
        }
    ];
}

/**
 * Send example the data of the example custom catalog to the basket.
 */
function handleCustomCatalogArticlesMessage(pQuery, pSendMessageCallback) {
    let tArticles = [];

    if (pQuery.catalogId == null || pQuery.catalogId === "exampleCustomCatalog") {
        if (pQuery.queryString == null || ("chair").indexOf(pQuery.queryString.toLowerCase()) === 0) {
            tArticles.push({
                id: "ch",
                label: "My Chair",
                articleNumber: "chair-1",
                manufacturerId: "XY",
                seriesId: "CH",
                catalogId: "exampleCustomCatalog",
                imageUrl: "https://integration.basket.pcon-solutions.com/example-data/custom-catalog/chair.jpg"
            });
        }
        if (pQuery.queryString == null || ("table").indexOf(pQuery.queryString.toLowerCase()) === 0) {
            tArticles.push({
                id: "ta",
                label: "My Table",
                articleNumber: "table-1",
                manufacturerId: "XY",
                seriesId: "TA",
                catalogId: "exampleCustomCatalog",
                imageUrl: "https://integration.basket.pcon-solutions.com/example-data/custom-catalog/table.jpg"
            });
        }
    }

    tArticles = tArticles.filter((article) => {
        if (pQuery.seriesId != null && article.seriesId !== pQuery.seriesId)
            return (false);
        if (pQuery.baseArticleNumber != null && article.articleNumber !== pQuery.baseArticleNumber)
            return (false);
        return (true);
    });

    const tMessage = {
        type: "wbk.customCatalogArticles",
        parameter: tArticles
    }
    pSendMessageCallback(tMessage);
}

/**
 * Send example data of custom afticles to the basket.
 */
function handleCustomArticleMessage(pQuery, pSendMessageCallback) {
    let tArticle;

    if (pQuery.articleId === "ch") {
        tArticle = {
            baseArticleNumber: "chair-1",
            manufacturerId: "XY",
            seriesId: "CH",
            shortText: "My Chair",
            longText: "This is my chair.",
            quantity: 2, //insert two chairs
            imageUrl: "https://integration.basket.pcon-solutions.com/example-data/custom-catalog/chair.jpg",
            salesPrice: {
                value: 300,
                currency: "EUR"
            }
        };
    } else if (pQuery.articleId === "ta") {
        tArticle = {
            baseArticleNumber: "table-1",
            manufacturerId: "XY",
            seriesId: "TA",
            shortText: "My Table",
            longText: "This is my table.",
            imageUrl: "https://integration.basket.pcon-solutions.com/example-data/custom-catalog/table.jpg",
            salesPrice: {
                value: 500,
                currency: "EUR"
            }
        };
    }

    const tMessage = {
        type: "wbk.customArticle",
        parameter: tArticle
    }
    pSendMessageCallback(tMessage);
}