/**
 * This function uses the PriceProfile plugin of the EAIWS to setup price conditions.
 */
async function setupPriceConditions(pSession) {
    //create purchase conditions
    const tPurchaseRules = [];
    const tRule1 = {};
    tRule1.manufacturer = "EG";
    tRule1.series = "OFFICE2";
    //tRule1.baseArticleNumber = "xxxx";
    //tRule1.finalArticleNumber = "xxxx";
    tRule1.value = "-20"; //20% discount
    tRule1.currency = ""; //empty or undefined means percantage
    tPurchaseRules.push(tRule1);

    const tRule2 = {};
    tRule2.manufacturer = "EG";
    tRule2.series = "OFFICE2";
    tRule2.baseArticleNumber = "4500"; //office chair
    tRule2.value = "-30"; //30% discount
    tPurchaseRules.push(tRule2);

    //create sales conditions
    const tSalesRules = [];
    const tRule3 = {};
    tRule3.manufacturer = "EG";
    tRule3.series = "OFFICE2";
    tRule3.value = "10"; //10% add charage
    tSalesRules.push(tRule3);

    //set conditions at PriceProfile-Plugin
    const tPluginUrl = egrWcf.utils.string.joinPath(pSession.baseUrl, "EAIWS/plugins/PriceProfile/v1", pSession.sessionId) + "/";
    await egrWcf.utils.async.ajax("PUT", tPluginUrl + "PDIP00", tPurchaseRules, { dataType: "json" }); //purchase
    await egrWcf.utils.async.ajax("PUT", tPluginUrl + "DIP10", tSalesRules, { dataType: "json" }); //sales
}

/**
 * Fill header data with example project information.
 */
function setExampleProjectData(pSession)
{
    const tData = new egrWcf.eaiws.project.ProjectData();
    tData.projectNumber = "my_quote_00001";
    tData.projectName = "My Quote";
    tData.company = "Example Company";
    tData.customerNumber = "000012";
    tData.projectTexts = [
        createProjectText("This is my header text", "HeaderText"),
        createProjectText("This is my footer text", "FooterText")
    ];

    return pSession.project.setProjectData(tData);
}

/**
 * Fill header data with example customer information.
 */
function setExampleCustomerAddress(pSession) {
    const tCommAddr = new egrWcf.eaiws.project.CommAddress();
    tCommAddr.scope = "Business";
    tCommAddr.type = "Mobile";
    tCommAddr.value = "0123/456789";

    const tContact = new egrWcf.eaiws.project.ContactData();
    tContact.contactType = "Support";
    tContact.firstName = "John";
    tContact.lastName = "Doe";
    tContact.title = "Mr.";
    tContact.commAddresses = [tCommAddr];

    const tAddress = new egrWcf.eaiws.project.AddressData();
    tAddress.addressType = "SoldTo";
    tAddress.name1 = "Example Company";
    tAddress.street = "Example Street 21";
    tAddress.postalCode = "123456";
    tAddress.location = "Berlin";
    tAddress.countryCode = "DE";
    tAddress.contacts = [tContact];

    return pSession.project.setAddressData(tAddress);
}

/**
 * Helper function to create an instance of `egrWcf.eaiws.project.ProjectText` with a given text as value.
 */
function createProjectText(pText, pType) {
    const tFormattedText = new egrWcf.eaiws.project.FormattedText();
    tFormattedText.format = "JSON";
    tFormattedText.language = "und"; //use undefined language
    tFormattedText.value = plainTextToEaiwsJson(pText);

    const tProjectText = new egrWcf.eaiws.project.ProjectText();
    tProjectText.type = pType;
    tProjectText.texts = [tFormattedText];

    return (tProjectText);
}

/**
 * Helper function to convert a plain text to the EAIWS JSON text format.
 */
function plainTextToEaiwsJson(pText) {
    const tLines = pText.trim().split("\n");
    const tParagraphContent = new Array();

    for (let i = 0; i < tLines.length; ++i) {
        let tLine = tLines[i];
        if (egrWcf.utils.string.isNotNullOrEmpty(tLine)) {
            //EAIWS will remove consecutive spaces, replace every second space with a "non breaking space" to avoid this
            tLine = tLine.replaceAll("  ", " \u00A0");
            tParagraphContent.push(tLine);
        }
        if (i < tLines.length - 1) {
            tParagraphContent.push(["br"]);
        }
    }

    const tParagraph = ["p", null, tParagraphContent];
    const tEaiwsText = ["iml", null, [tParagraph]];
    return (JSON.stringify(tEaiwsText));
}